==> haskell-mono-traversable-1.0.12.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.12.0
id: mono-traversable-1.0.12.0-2ZvK6RvZ1aSIDuV8Uz5kAc
key: mono-traversable-1.0.12.0-2ZvK6RvZ1aSIDuV8Uz5kAc
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, John Wiegley, Greg Weber
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
abi: 034d32f63dbd3ed4575e88bc60412d61
exposed: True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
import-dirs: /usr/lib/ghc-8.6.5/site-local/mono-traversable-1.0.12.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mono-traversable-1.0.12.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mono-traversable-1.0.12.0
hs-libraries: HSmono-traversable-1.0.12.0-2ZvK6RvZ1aSIDuV8Uz5kAc
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.12.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.12.0
id: mono-traversable-1.0.12.0-84lDrTsXjxX5gwp66dqLDj
key: mono-traversable-1.0.12.0-84lDrTsXjxX5gwp66dqLDj
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, John Wiegley, Greg Weber
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
abi: b86c8b6ac802e1c2585afa5fe008713a
exposed: True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
import-dirs: /usr/lib/ghc-8.6.5/site-local/mono-traversable-1.0.12.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mono-traversable-1.0.12.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mono-traversable-1.0.12.0
hs-libraries: HSmono-traversable-1.0.12.0-84lDrTsXjxX5gwp66dqLDj
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
